==> vtk6-6.3.0-4-aarch64.pkg.tar.xz: vtk/vtkCurvatures.java <==
// java wrapper for vtkCurvatures object
//

package vtk;
import vtk.*;

public class vtkCurvatures extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCurvatureType_2(int id0);
  public void SetCurvatureType(int id0)
    { SetCurvatureType_2(id0); }

  private native int GetCurvatureType_3();
  public int GetCurvatureType()
    { return GetCurvatureType_3(); }

  private native void SetCurvatureTypeToGaussian_4();
  public void SetCurvatureTypeToGaussian()
    { SetCurvatureTypeToGaussian_4(); }

  private native void SetCurvatureTypeToMean_5();
  public void SetCurvatureTypeToMean()
    { SetCurvatureTypeToMean_5(); }

  private native void SetCurvatureTypeToMaximum_6();
  public void SetCurvatureTypeToMaximum()
    { SetCurvatureTypeToMaximum_6(); }

  private native void SetCurvatureTypeToMinimum_7();
  public void SetCurvatureTypeToMinimum()
    { SetCurvatureTypeToMinimum_7(); }

  private native void SetInvertMeanCurvature_8(int id0);
  public void SetInvertMeanCurvature(int id0)
    { SetInvertMeanCurvature_8(id0); }

  private native int GetInvertMeanCurvature_9();
  public int GetInvertMeanCurvature()
    { return GetInvertMeanCurvature_9(); }

  private native void InvertMeanCurvatureOn_10();
  public void InvertMeanCurvatureOn()
    { InvertMeanCurvatureOn_10(); }

  private native void InvertMeanCurvatureOff_11();
  public void InvertMeanCurvatureOff()
    { InvertMeanCurvatureOff_11(); }

  public vtkCurvatures() { super(); }

  public vtkCurvatures(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkCurvatures.java <==
// java wrapper for vtkCurvatures object
//

package vtk;
import vtk.*;

public class vtkCurvatures extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCurvatureType_2(int id0);
  public void SetCurvatureType(int id0)
    { SetCurvatureType_2(id0); }

  private native int GetCurvatureType_3();
  public int GetCurvatureType()
    { return GetCurvatureType_3(); }

  private native void SetCurvatureTypeToGaussian_4();
  public void SetCurvatureTypeToGaussian()
    { SetCurvatureTypeToGaussian_4(); }

  private native void SetCurvatureTypeToMean_5();
  public void SetCurvatureTypeToMean()
    { SetCurvatureTypeToMean_5(); }

  private native void SetCurvatureTypeToMaximum_6();
  public void SetCurvatureTypeToMaximum()
    { SetCurvatureTypeToMaximum_6(); }

  private native void SetCurvatureTypeToMinimum_7();
  public void SetCurvatureTypeToMinimum()
    { SetCurvatureTypeToMinimum_7(); }

  private native void SetInvertMeanCurvature_8(int id0);
  public void SetInvertMeanCurvature(int id0)
    { SetInvertMeanCurvature_8(id0); }

  private native int GetInvertMeanCurvature_9();
  public int GetInvertMeanCurvature()
    { return GetInvertMeanCurvature_9(); }

  private native void InvertMeanCurvatureOn_10();
  public void InvertMeanCurvatureOn()
    { InvertMeanCurvatureOn_10(); }

  private native void InvertMeanCurvatureOff_11();
  public void InvertMeanCurvatureOff()
    { InvertMeanCurvatureOff_11(); }

  public vtkCurvatures() { super(); }

  public vtkCurvatures(long id) { super(id); }
  public native long   VTKInit();

}
